"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
var FileObject_1 = require("../utils/FileObject");
/**
 * @api public
 * AuthAPI - provides methods to interact with the Auth API
 */
var AuthAPI = /** @class */ (function (_super) {
    tslib_1.__extends(AuthAPI, _super);
    function AuthAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `POST /api/auth/username-check/` - Promises to check if a username is available
     * @param {string} username - The desired username
     * @returns - a boolean
     */
    AuthAPI.prototype.isUsernameAvailable = function (username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('username-check');
                this.requiresToken = false;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        return _this.post({ username: username })
                            .then(function () { return resolve(true); })
                            .catch(function (err) {
                            if (err.response && err.response.status === 400) {
                                return resolve(false);
                            }
                            return reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * `POST /api/auth/email-check/` - Promises to check if an email address is available
     * @param {string} email - The desired email address
     * @returns - a boolean
     */
    AuthAPI.prototype.isEmailAvailable = function (email) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var _this = this;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('email-check');
                this.requiresToken = false;
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        return _this.post({ email: email })
                            .then(function () { return resolve(true); })
                            .catch(function (err) {
                            if (err.response && err.response.status === 400) {
                                return resolve(false);
                            }
                            return reject(err);
                        });
                    })];
            });
        });
    };
    /**
     * `POST /api/auth/register/` (urlencoded) - Promises to create a user
     * @param {UserCreatorOpts} payload - The user's properties
     * @returns - the created user
     */
    AuthAPI.prototype.createUser = function (payload) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var email, token, name, isOfLegalAge, areGuidelinesAccepted, password, body;
            return tslib_1.__generator(this, function (_a) {
                email = payload.email, token = payload.token, name = payload.name, isOfLegalAge = payload.isOfLegalAge, areGuidelinesAccepted = payload.areGuidelinesAccepted, password = payload.password;
                body = {
                    email: email,
                    token: token,
                    name: name,
                    is_of_legal_age: isOfLegalAge.toString(),
                    are_guidelines_accepted: areGuidelinesAccepted.toString(),
                    password: password
                };
                if (payload.avatar) {
                    body['avatar'] = new FileObject_1.FileObject(payload.avatar);
                }
                this._paths.push('register');
                this.requiresToken = false;
                return [2 /*return*/, this.postFormdata(body)];
            });
        });
    };
    /**
     * `PATCH /api/auth/user/` (urlencoded) - Promises to create a user
     * @param {IUpdateUser} payload - The user's properties
     * @returns - the updated user
     */
    AuthAPI.prototype.updateUser = function (payload) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var avatar, cover, name, username, url, followersCountVisible, bio, location, body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user');
                avatar = payload.avatar, cover = payload.cover, name = payload.name, username = payload.username, url = payload.url, followersCountVisible = payload.followersCountVisible, bio = payload.bio, location = payload.location;
                body = {};
                if (avatar !== undefined) {
                    body.avatar = avatar === null
                        ? avatar
                        : new FileObject_1.FileObject(avatar);
                }
                if (cover !== undefined) {
                    body.cover = cover === null
                        ? cover
                        : new FileObject_1.FileObject(cover);
                }
                if (name) {
                    body.name = name;
                }
                if (username) {
                    body.username = username;
                }
                if (url) {
                    body.url = url;
                }
                if (bio) {
                    body.bio = bio;
                }
                if (followersCountVisible !== undefined) {
                    body.followers_count_visible = followersCountVisible;
                }
                if (location) {
                    body.location = location;
                }
                return [2 /*return*/, this.patchFormdata(body)];
            });
        });
    };
    /**
    * `PATCH /api/auth/user/settings/` (urlencoded) - Promises to update the user's email
    * @param {string} email - The desired email address
    */
    AuthAPI.prototype.updateUserEmail = function (email) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user', 'settings');
                return [2 /*return*/, this.patchFormdata({ email: email })];
            });
        });
    };
    /**
     * `PATCH /api/auth/user/settings/` (urlencoded) - Promises to update the user's passord
     * @param {string} currentPassword - The user's current password
     * @param {string} newPassword - The user's desired new password
     */
    AuthAPI.prototype.updateUserPassword = function (currentPassword, newPassword) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user', 'settings');
                return [2 /*return*/, this.patchFormdata({
                        current_password: currentPassword,
                        new_password: newPassword
                    })];
            });
        });
    };
    /**
     * `POST /api/auth/email/verify/` - Promises to verify a user's email
     * @param {string} token - The verification token
     */
    AuthAPI.prototype.verifyEmailWithToken = function (token) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('email', 'verify');
                return [2 /*return*/, this.post({ token: token })];
            });
        });
    };
    /**
     * `GET /api/auth/user/` - Promises to get a user by auth token
     * @param {string} authToken - The authentication token
     */
    AuthAPI.prototype.getUserWithAuthToken = function (authToken) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = false;
                this._headers['Authorization'] = "Token: " + authToken;
                this._paths.push('user');
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/user/` - Promises to get a user by username
     * @param {string} username - The username to search for
     * @param {boolean} authenticatedRequest - Checks whether the request is authenticated
     */
    AuthAPI.prototype.getUserWithUsername = function (username, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                if (!authenticatedRequest) {
                    this.requiresToken = false;
                }
                this._paths.push('users', encodeURIComponent(username));
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/user/` - Promises to get a user by a certain query
     * @param {string} query - The search query
     * @param {boolean} authenticatedRequest - Checks whether the request is authenticated
     */
    AuthAPI.prototype.getUsersWithQuery = function (query, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = authenticatedRequest;
                this._paths.push('users');
                this._params.query = query;
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/linked-users/search/` - Promises to search a linked user
     * @param {ISearchLinkedUsers}
     */
    AuthAPI.prototype.searchLinkedUsers = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('linked-users', 'search');
                this._params.query = opts.query;
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.withCommunity) {
                    this._params.with_community = opts.withCommunity;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/linked-users/` - Promises to get an array of linked users
     * @param {IGetLinkedUsers}
     * @param {boolean} authenticatedRequest - Checks whether the request is authenticated
     */
    AuthAPI.prototype.getLinkedUsers = function (opts, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = authenticatedRequest;
                this._paths.push('linked-users');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.withCommunity) {
                    this._params.with_community = opts.withCommunity;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/blocked-users/search/` - Promises to search between blocked users
     * @param {string} query - The search query
     * @param {number | undefined} count - The max number of results
     */
    AuthAPI.prototype.searchBlockedUsers = function (query, count) {
        if (count === void 0) { count = undefined; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('blocked-users', 'search');
                this._params.query = query;
                if (count !== undefined) {
                    this._params.count = count;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/blocked-users/` - Promises to get an array of blocked users
     * @param {LimitationParams} opts - Query limitation parameters
     * @param {boolean} authenticatedRequest - Checks whether the request is authenticated
     */
    AuthAPI.prototype.getBlockedUsers = function (opts, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = authenticatedRequest;
                this._paths.push('blocked-users');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/auth/users/:username/block/` - Promises to block a user by username
     * @param {string} username - The username of the user to block
     */
    AuthAPI.prototype.blockUserWithName = function (username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('users', encodeURIComponent(username), 'block');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    /**
     * `POST /api/auth/users/:username/unblock/` - Promises to unblock a user by username
     * @param {string} username - The username of the user to unblock
     */
    AuthAPI.prototype.unblockUserWithName = function (username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('users', encodeURIComponent(username), 'unblock');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    /**
     * `GET /api/auth/followers/search` - Promises to search between followers
     * @param {ISearchFollowers}
     */
    AuthAPI.prototype.searchFollowers = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('followers', 'search');
                this._params.query = opts.query;
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/followers/` - Promises to get an array of followers
     * @param {LimitationParams} opts - Query limitation parameters
     * @param {boolean} authenticatedRequest - Checks whether the request is authenticated
     */
    AuthAPI.prototype.getFollowers = function (opts, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = authenticatedRequest;
                this._paths.push('followers');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/followings/search` - Promises to search between followings
     * @param {ISearchFollowings}
     */
    AuthAPI.prototype.searchFollowings = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('followings', 'search');
                this._params.query = opts.query;
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/auth/followings/` - Promises to get an array of followings
     * @param {LimitationParams} opts - Query limitation parameters
     * @param {boolean} authenticatedRequest - Checks whether the request is authenticated
     */
    AuthAPI.prototype.getFollowings = function (opts, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = authenticatedRequest;
                this._paths.push('followings');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/auth/login/` - Promises to log a user in
     * @param {string} username - The username of the user
     * @param {string} password - The password of the user
     */
    AuthAPI.prototype.login = function (username, password) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('login');
                this.requiresToken = false;
                return [2 /*return*/, this.post({ username: username, password: password })];
            });
        });
    };
    /**
     * `POST /api/auth/password/reset/` - Promises to initiate a password reset process
     * @param {IRequestPasswordReset} opts
     */
    AuthAPI.prototype.requestPasswordReset = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = false;
                this._paths.push('password', 'reset');
                return [2 /*return*/, this.post(opts)];
            });
        });
    };
    /**
     * `POST /api/auth/password/verify/` - Promises to verify a password
     * @param {IVerifyPasswordReset} opts
     */
    AuthAPI.prototype.verifyPasswordReset = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this.requiresToken = false;
                this._paths.push('password', 'verify');
                return [2 /*return*/, this.post({
                        new_password: opts.password,
                        token: opts.token
                    })];
            });
        });
    };
    /**
     * `GET /api/auth/user/notifications-settings/` - Promises to retrieve the user's notification settings
     */
    AuthAPI.prototype.getAuthenticatedUserNotificationSettings = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user', 'notifications-settings');
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/auth/user/notifications-settings/` - Promises to update the user's notification settings
     * @param {IUpdateNotificationSettings} opts
     */
    AuthAPI.prototype.updateAuthenticatedUserNotificationSettings = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user', 'notifications-settings');
                return [2 /*return*/, this.post(opts)];
            });
        });
    };
    /**
     * `POST /api/auth/user/accept-guidelines/` - Promises to accept the user guidelines
     */
    AuthAPI.prototype.acceptGuidelines = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user', 'accept-guidelines');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    /**
     * `GET /auth/auth/user/languages/` - Promises to get the user's languages
     */
    AuthAPI.prototype.getAllLanguages = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user', 'languages');
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/auth/user/languages/` - Promises to set a new user language
     * @param {number} languageId - The id of the desired language
     */
    AuthAPI.prototype.setNewLanguage = function (languageId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('user', 'languages');
                return [2 /*return*/, this.post({
                        language_id: languageId.toString()
                    })];
            });
        });
    };
    /**
     * `POST /api/auth/users/:username/report/` - Promises to report a user
     * @param {IReportUser} opts
     */
    AuthAPI.prototype.reportUser = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('users', encodeURIComponent(opts.username), 'report');
                body = {
                    category_id: opts.moderationCategoryId
                };
                if (opts.description) {
                    body.description = opts.description;
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    return AuthAPI;
}(APIRequest_1.APIRequest));
exports.AuthAPI = AuthAPI;
