"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var buildUrl_1 = tslib_1.__importDefault(require("./buildUrl"));
var requestStrategies_1 = require("./requestStrategies");
require("isomorphic-form-data");
/**
 * @api
 */
var APIRequest = /** @class */ (function () {
    function APIRequest(opts) {
        this._paths = [];
        this._params = {};
        this._headers = {};
        this.requiresToken = true;
        this._okuna = opts.okuna;
        this._endpoint = opts.endpoint;
        this._paths = [this._endpoint];
        this._url = "" + this._okuna.apiUrl + this._endpoint;
        this._api = requestStrategies_1.getRequestStrategy(this._okuna.requestStrategy);
    }
    /**
     * generateHeaders()
     * A function used to generate the headers that need to be
     * passed to the request performee.
     * @returns {object}
     */
    APIRequest.prototype.generateHeaders = function (contentType) {
        var _a;
        if (contentType === void 0) { contentType = null; }
        var headers = {
            'Accept': 'application/json'
        };
        if (contentType !== 'auto') {
            Object.assign(headers, { 'Content-Type': contentType || 'application/json' });
        }
        if (this._okuna.magicHeaderName && this._okuna.magicHeaderValue) {
            Object.assign(headers, (_a = {}, _a[this._okuna.magicHeaderName] = this._okuna.magicHeaderValue, _a));
        }
        if (this.requiresToken) {
            if (!this._okuna.authToken) {
                throw new Error('Authorization token not provided.');
            }
            Object.assign(headers, { 'Authorization': "Token " + this._okuna.authToken });
        }
        return headers;
    };
    /**
     * constructFormdata()
     * Constructs a FormData instance from an object.
     * @param {object} opts - the object to generate the FormData from
     * @returns {FormData}
     */
    APIRequest.prototype._constructFormdata = function (opts) {
        if (opts === void 0) { opts = null; }
        var form = new FormData();
        if (!opts) {
            return form;
        }
        Object.keys(opts).forEach(function (key) {
            var value = opts[key];
            // istanbul ignore next
            if (value.isValidFileObject) {
                return form.append(key, value.file, value.name);
            }
            return form.append(key, value);
        });
        return form;
    };
    /**
     * get()
     * GET request
     * @returns {Promise<any>}
     */
    APIRequest.prototype.get = function () {
        var _this = this;
        this._headers = this.generateHeaders();
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.get(_this._url, { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    /**
     * put()
     * PUT request
     * @param {object} body - Request body
     */
    APIRequest.prototype.put = function (body) {
        var _this = this;
        this._headers = this.generateHeaders();
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.put(_this._url, JSON.stringify(body), { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    /**
     * post()
     * POST request
     * @param {object} body - Request body
     */
    APIRequest.prototype.post = function (body) {
        var _this = this;
        this._headers = this.generateHeaders();
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.post(_this._url, JSON.stringify(body), { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    /**
     * patch()
     * PATCH request
     * @param {object} body - Request body
     */
    APIRequest.prototype.patch = function (body) {
        var _this = this;
        this._headers = this.generateHeaders();
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.patch(_this._url, JSON.stringify(body), { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    /**
     * delete()
     * DELETE request
     * @returns {Promise<any>}
     */
    APIRequest.prototype.delete = function () {
        var _this = this;
        this._headers = this.generateHeaders();
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.delete(_this._url, { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    /**
     * putFormdata()
     * PUT request (multipart/form-data, application/x-www-form-urlencoded)
     */
    APIRequest.prototype.putFormdata = function (body) {
        var _this = this;
        var form = this._constructFormdata(body);
        this._headers = this.generateHeaders('auto');
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.put(_this._url, form, { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    /**
     * postFormdata()
     * POST request (multipart/form-data, application/x-www-form-urlencoded)
     */
    APIRequest.prototype.postFormdata = function (body) {
        var _this = this;
        var form = this._constructFormdata(body);
        this._headers = this.generateHeaders('auto');
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.post(_this._url, form, { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    /**
     * patchFormdata()
     * PATCH request (multipart/form-data, application/x-www-form-urlencoded)
     */
    APIRequest.prototype.patchFormdata = function (body) {
        var _this = this;
        var form = this._constructFormdata(body);
        this._headers = this.generateHeaders('auto');
        this._url = buildUrl_1.default(this._okuna.apiUrl, this._paths, this._params);
        return new Promise(function (resolve, reject) {
            return _this._api.patch(_this._url, form, { headers: _this._headers })
                .then(function (res) { return resolve(res.data); })
                .catch(function (err) { return reject(err); });
        });
    };
    return APIRequest;
}());
exports.APIRequest = APIRequest;
